==> darky-0.6.7.tgz: package/README.md <==
# [darky.js](https://github.com/jb1905/darky.js)

[![NPM version](http://img.shields.io/npm/v/darky.svg?style=flat-square)](https://www.npmjs.com/package/darky)
[![NPM downloads](http://img.shields.io/npm/dm/darky.svg?style=flat-square)](https://www.npmjs.com/package/darky)

## How to Install
At the beginning connect the library with Your project:

**&bull; using script tag in HTML:**
```html
<script src="/directory/to/library/folder/darky.js"></script>
```

**&bull; or via command line:**
```sh
$ npm install darky
$ yarn add darky
```

## Getting Started
**If you added library via package manager use CommonJS/ES6 import:**
```js
const Darky = require('darky'); // CommonJS
import Darky from 'darky'; // ES6
```

Next use library with:

**&bull; Vanilla JavaScript e.g:**
```js
const darky = new Darky({
  // options...
});
```

## Functions
**&bull; Switch between light and dark mode:**
```js
darky.toggle();
```

**• Switch mode automatically (based on time, location and sun position):**
```js
darky.auto();
```

**• Reset localStorage data:**
```js
darky.reset();
```

## Options
Name | Type | Default | Description | Available options
-|-|-|-|-
**lightClass** | string | ` ` | Class added to body when light mode is active | Name of the class
**darkClass** | string | `dark` | Class added to body when dark mode is active | Name of the class
**cache** | boolean | `true` | cache location coordinates in local storage for one day | `true` (enable), `false` (disable)
**cacheClear** | boolean | `true` | clear location coordinates in local storage everyday at midnight | `true` (enable), `false` (disable)
**auto** | boolean | `true` | enable smart switch on script init | `true` (enable), `false` (disable)
**onAuto** | function | `null` | callback on smart switch | `() => { // code }`
**onLight** | function | `null` | callback when dark mode is disabled | `() => { // code }`
**onDark** | function | `null` | callback when dark mode is enabled | `() => { // code }`
**onToggle** | function | `null` | callback on dark/light mode toggle | `() => { // code }`
**onCacheClear** | function | `null` | callback when location coordinates and midnight time in local storage cleared | `() => { // code }`
**onReset** | function | `null` | callback on localStorage reset | `() => { // code }`

## Event
`smartDark` event will output sun position times and user geolocation latitude & longitude

## License
This project is licensed under the MIT License © 2018-present Jakub Biesiada

==> darky-1.0.0.tgz: package/README.md <==
# [darky.js](https://github.com/jb1905/darky.js)

[![NPM version](http://img.shields.io/npm/v/darky.svg?style=flat-square)](https://www.npmjs.com/package/darky)
[![NPM downloads](http://img.shields.io/npm/dm/darky.svg?style=flat-square)](https://www.npmjs.com/package/darky)

## How to Install
At the beginning install the library in Your project via npm or Yarn:
```sh
$ npm install darky
$ yarn add darky
```

## Getting Started
**Connect using script tag in HTML:**
```html
<script src="/directory/to/library/folder/darky.js"></script>
```

**Or CommonJS/ES6 import:**
```js
const Darky = require('darky'); // CommonJS
import Darky from 'darky'; // ES6
```

Next use library with:

**&bull; Vanilla JavaScript e.g:**
```js
const darky = new Darky({
  // options...
});
```

## Functions
**&bull; Switch between light and dark mode:**
```js
darky.toggle();
```

**• Switch mode automatically (based on time, location and sun position):**
```js
darky.auto();
```

**• Reset localStorage data:**
```js
darky.reset();
```

## Options
Name | Type | Default | Description | Available options
-|-|-|-|-
**lightClass** | string | ` ` | Class added to body when light mode is active | Name of the class
**darkClass** | string | `dark` | Class added to body when dark mode is active | Name of the class
**cache** | boolean | `true` | cache location coordinates in local storage for one day | `true` (enable), `false` (disable)
**cacheClear** | boolean | `true` | clear location coordinates in local storage everyday at midnight | `true` (enable), `false` (disable)
**auto** | boolean | `true` | enable smart switch on script init | `true` (enable), `false` (disable)
**onAuto** | function | `null` | callback on smart switch | `() => { // code }`
**onLight** | function | `null` | callback when dark mode is disabled | `() => { // code }`
**onDark** | function | `null` | callback when dark mode is enabled | `() => { // code }`
**onToggle** | function | `null` | callback on dark/light mode toggle | `() => { // code }`
**onCacheClear** | function | `null` | callback when location coordinates and midnight time in local storage cleared | `() => { // code }`
**onReset** | function | `null` | callback on localStorage reset | `() => { // code }`

## Event
`smartDark` event will output sun position times and user geolocation latitude & longitude

## License
This project is licensed under the MIT License © 2018-present Jakub Biesiada
